==> haskell-monad-par-0.3.4.8-40-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-par.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-par
version: 0.3.4.8
id: monad-par-0.3.4.8-2aAP168J30IIsAygqMiBj8
key: monad-par-0.3.4.8-2aAP168J30IIsAygqMiBj8
license: BSD-3-Clause
copyright: (c) Simon Marlow 2011
maintainer: Simon Marlow <marlowsd@gmail.com>, Ryan Newton <rrnewton@gmail.com>
author: Simon Marlow, Ryan Newton
stability: Experimental
homepage: https://github.com/simonmar/monad-par
synopsis: A library for parallel programming based on a monad
description:
    The '\''Par'\'' monad offers a simple API for parallel programming.  The
    library works for parallelising both pure and @IO@ computations,
    although only the pure version is deterministic.  The default
    implementation provides a work-stealing scheduler and supports
    forking tasks that are much lighter weight than IO-threads.
    .
    For complete documentation see "Control.Monad.Par".
    .
    Some examples of use can be found in the @examples/@ directory of
    the source package.
    .
    Other related packages:
    .
    * @abstract-par@ provides the type classes that abstract over different
    implementations of the @Par@ monad.
    .
    * @monad-par-extras@ provides extra combinators and monad transformers layered on top of
    the @Par@ monad.
    .
    Changes in 0.3.4 relative to 0.3:
    .
    * Fix bugs that cause "thread blocked indefinitely on MVar" crashes.
    .
    * Added "Control.Monad.Par.IO"
category: Control,Parallelism,Monads
abi: f9a598eebc950b598ae42d413954e800
exposed: True
exposed-modules:
    Control.Monad.Par Control.Monad.Par.IO
    Control.Monad.Par.Scheds.Direct Control.Monad.Par.Scheds.Sparks
    Control.Monad.Par.Scheds.Trace
    Control.Monad.Par.Scheds.TraceInternal
hidden-modules: Control.Monad.Par.Scheds.DirectInternal
import-dirs: /usr/lib/ghc-8.6.5/site-local/monad-par-0.3.4.8
library-dirs: /usr/lib/ghc-8.6.5/site-local/monad-par-0.3.4.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/monad-par-0.3.4.8
hs-libraries: HSmonad-par-0.3.4.8-2aAP168J30IIsAygqMiBj8
depends:
    abstract-deque-0.3-Ea960a5KENXK2d35e54eQH
    abstract-par-0.3.3-7eQ2qvh3JUrFV0IzAkpSDj array-0.5.3.0
    base-4.12.0.0 containers-0.6.0.1 deepseq-1.4.4.0
    monad-par-extras-0.3.3-IYaP7tDu7QC3qifVidMKSY mtl-2.2.2
    mwc-random-0.14.0.0-2pxNHDgDQNDAJj9EQzqdx2
    parallel-3.2.2.0-EGl5SOk48TWHAD161C93aQ
haddock-interfaces: /usr/share/doc/haskell-monad-par/html/monad-par.haddock
haddock-html: /usr/share/doc/haskell-monad-par/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-par-0.3.4.8-51-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-par.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-par
version: 0.3.4.8
id: monad-par-0.3.4.8-9K5fXgEogfdFYzoBNl49sk
key: monad-par-0.3.4.8-9K5fXgEogfdFYzoBNl49sk
license: BSD-3-Clause
copyright: (c) Simon Marlow 2011
maintainer: Simon Marlow <marlowsd@gmail.com>, Ryan Newton <rrnewton@gmail.com>
author: Simon Marlow, Ryan Newton
stability: Experimental
homepage: https://github.com/simonmar/monad-par
synopsis: A library for parallel programming based on a monad
description:
    The '\''Par'\'' monad offers a simple API for parallel programming.  The
    library works for parallelising both pure and @IO@ computations,
    although only the pure version is deterministic.  The default
    implementation provides a work-stealing scheduler and supports
    forking tasks that are much lighter weight than IO-threads.
    .
    For complete documentation see "Control.Monad.Par".
    .
    Some examples of use can be found in the @examples/@ directory of
    the source package.
    .
    Other related packages:
    .
    * @abstract-par@ provides the type classes that abstract over different
    implementations of the @Par@ monad.
    .
    * @monad-par-extras@ provides extra combinators and monad transformers layered on top of
    the @Par@ monad.
    .
    Changes in 0.3.4 relative to 0.3:
    .
    * Fix bugs that cause "thread blocked indefinitely on MVar" crashes.
    .
    * Added "Control.Monad.Par.IO"
category: Control,Parallelism,Monads
abi: 97cbfebccb9273959bc3450bd9d88664
exposed: True
exposed-modules:
    Control.Monad.Par Control.Monad.Par.IO
    Control.Monad.Par.Scheds.Direct Control.Monad.Par.Scheds.Sparks
    Control.Monad.Par.Scheds.Trace
    Control.Monad.Par.Scheds.TraceInternal
hidden-modules: Control.Monad.Par.Scheds.DirectInternal
import-dirs: /usr/lib/ghc-8.6.5/site-local/monad-par-0.3.4.8
library-dirs: /usr/lib/ghc-8.6.5/site-local/monad-par-0.3.4.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/monad-par-0.3.4.8
hs-libraries: HSmonad-par-0.3.4.8-9K5fXgEogfdFYzoBNl49sk
depends:
    abstract-deque-0.3-Ea960a5KENXK2d35e54eQH
    abstract-par-0.3.3-7eQ2qvh3JUrFV0IzAkpSDj array-0.5.3.0
    base-4.12.0.0 containers-0.6.0.1 deepseq-1.4.4.0
    monad-par-extras-0.3.3-Jixxn88j7chDpr56yJS3e0 mtl-2.2.2
    mwc-random-0.14.0.0-2pxNHDgDQNDAJj9EQzqdx2
    parallel-3.2.2.0-EGl5SOk48TWHAD161C93aQ
haddock-interfaces: /usr/share/doc/haskell-monad-par/html/monad-par.haddock
haddock-html: /usr/share/doc/haskell-monad-par/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
